
{{/*
Create the name of the service account to use
*/}}
{{- define "adminFrontend.serviceAccountName" -}}
{{- if .Values.serviceAccount.create -}}
    {{ default (include "common.names.fullname" .) .Values.serviceAccount.name }}
{{- else -}}
    {{ default "default" .Values.serviceAccount.name }}
{{- end -}}
{{- end -}}

{{/*
Return the proper Docker image registry secret names
*/}}
{{- define "adminFrontend.imagePullSecrets" -}}
{{ include "common.images.pullSecrets" (dict "images" (list .Values.image) "global" .Values.global) }}
{{- end -}}

{{/*
Return true if a secret object for Admin-frontend should be created
*/}}
{{- define "adminFrontend.createSecret" -}}
{{- if or (not .Values.adminFrontend.existingSecret) (and (not .Values.adminFrontend.smtp.existingSecret) .Values.adminFrontend.smtp.password .Values.adminFrontend.smtp.enabled) }}
    {{- true -}}
{{- end -}}
{{- end -}}

{{/*
Return the Admin-frontend secret name
*/}}
{{- define "adminFrontend.secretName" -}}
{{- if .Values.adminFrontend.existingSecret }}
    {{- printf "%s" .Values.adminFrontend.existingSecret -}}
{{- else -}}
    {{- printf "%s-adminFrontend" (include "common.names.fullname" .) -}}
{{- end -}}
{{- end -}}

{{/*
Return the Admin-frontend SMTP secret name
*/}}
{{- define "adminFrontend.smtp.secretName" -}}
{{- if .Values.adminFrontend.smtp.existingSecret }}
    {{- printf "%s" .Values.adminFrontend.smtp.existingSecret -}}
{{- else -}}
    {{- printf "%s-adminFrontend" (include "common.names.fullname" .) -}}
{{- end -}}
{{- end -}}

{{/*
Return true if Admin-frontend SMTP uses password authentication
*/}}
{{- define "adminFrontend.smtp.password.enabled" -}}
{{- if and (or .Values.adminFrontend.smtp.password .Values.adminFrontend.smtp.existingSecret) .Values.adminFrontend.smtp.enabled }}
    {{- true -}}
{{- end -}}
{{- end -}}

{{/*
Get the user defined LoadBalancerIP for this release
Note, returns 127.0.0.1 if using ClusterIP.
*/}}
{{- define "adminFrontend.serviceIP" -}}
{{- if eq .Values.service.type "ClusterIP" -}}
127.0.0.1
{{- else -}}
{{- .Values.service.loadBalancerIP | default "" -}}
{{- end -}}
{{- end -}}

{{/*
Gets the host to be used for this application.
If not using ClusterIP, or if a host or LoadBalancerIP is not defined, the value will be empty
*/}}
{{- define "adminFrontend.host" -}}
{{- $host := .Values.adminFrontend.host | default "" -}}
{{- default (include "adminFrontend.serviceIP" .) $host -}}
{{- end -}}

{{/*
Return the proper Admin-frontend image name
*/}}
{{- define "adminFrontend.image" -}}
{{ include "common.images.image" (dict "imageRoot" .Values.image "global" .Values.global) }}
{{- end -}}

{{/*
Return the proper Storage Class
*/}}
{{- define "adminFrontend.storageClass" -}}
{{- include "common.storage.class" (dict "persistence" .Values.persistence "global" .Values.global) -}}
{{- end -}}
